package org.shokai.samplegeofence;

import android.app.IntentService;
import android.app.Notification;
import android.app.PendingIntent;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.support.v4.app.NotificationCompat;
import android.support.v4.app.NotificationManagerCompat;
import android.util.Log;

import com.google.android.gms.location.Geofence;
import com.google.android.gms.location.GeofencingEvent;

public class GeofenceReceiveService extends IntentService {

    public GeofenceReceiveService() {
        super("GeofenceReceiveService");
    }

    @Override
    protected void onHandleIntent(Intent intent) {
        GeofencingEvent event = GeofencingEvent.fromIntent(intent);
        if (event != null && !event.hasError()) {
            int transition = event.getGeofenceTransition();
            Geofence fence = event.getTriggeringGeofences().get(0);
            String id = fence.getRequestId();
            if (id.equals("新宿駅")){
                switch (transition) {
                    case Geofence.GEOFENCE_TRANSITION_ENTER:
                        Log.i("Geofence", "新宿駅に入った");
                        // ここでAndroid Wearに通知を送る、などが可能
                        sendNotification("Geofence", "新宿駅に入った");
                        break;
                    case Geofence.GEOFENCE_TRANSITION_EXIT:
                        Log.i("Geofence", "新宿駅から出た");
                        sendNotification("Geofence", "新宿駅から出た");
                        break;
                }
            }
        }
    }

    private void sendNotification(String title, String text) {
        // Android本体で地図を開くインテント
        Intent intent = new Intent(Intent.ACTION_VIEW, Uri.parse("geo:35.690921,139.700258"));
        PendingIntent pIntent = PendingIntent.getActivity(this, 0, intent, 0);

        // アイコン（大）はAndroid Wearでは背景画像になる
        Bitmap largeIcon = BitmapFactory.decodeResource(
                getResources(), android.R.drawable.ic_menu_mapmode);

        Notification notif = new NotificationCompat.Builder(this)
                .setContentTitle(title)
                .setContentText(text)
                .setSmallIcon(android.R.drawable.btn_default_small)
                .setLargeIcon(largeIcon)
                .addAction(android.R.drawable.ic_dialog_map, "Mapを開く", pIntent) // アクション追加
                .build();

        // 通知する
        NotificationManagerCompat.from(this).notify(0, notif);
    }

}
